=== modified file 'mysys/my_error.c'
--- mysys/my_error.c	2008-08-01 23:59:59 +0000
+++ mysys/my_error.c	2008-08-05 18:04:31 +0000
@@ -14,11 +14,11 @@
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */
 
 #include "mysys_priv.h"
+#include <libdrizzle/gettext.h>
 #include "mysys_err.h"
 #include <mystrings/m_string.h>
 #include <stdarg.h>
 #include <mystrings/m_ctype.h>
-#include <libdrizzle/gettext.h>
 
 /* Define some external variables for error handling */
 

=== modified file 'mysys/my_getopt.c'
--- mysys/my_getopt.c	2008-08-01 19:02:15 +0000
+++ mysys/my_getopt.c	2008-08-05 18:04:31 +0000
@@ -14,6 +14,7 @@
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */
 
 #include "mysys_priv.h"
+#include <libdrizzle/gettext.h>
 
 #include <mystrings/m_string.h>
 #include <stdlib.h>
@@ -79,9 +80,9 @@
   va_list args;
   va_start(args, format);
   if (level == WARNING_LEVEL)
-    fprintf(stderr, "%s", "Warning: ");
+    fprintf(stderr, "%s", _("Warning: "));
   else if (level == INFORMATION_LEVEL)
-    fprintf(stderr, "%s", "Info: ");
+    fprintf(stderr, "%s", _("Info: "));
   vfprintf(stderr, format, args);
   va_end(args);
   fputc('\n', stderr);
@@ -341,8 +342,8 @@
 	{
 	  if (my_getopt_print_errors)
 	    fprintf(stderr,
-		    "%s: %s: Option '%s' used, but is disabled\n", my_progname,
-		    option_is_loose ? "WARNING" : "ERROR", opt_str);
+		    _("%s: %s: Option '%s' used, but is disabled\n"), my_progname,
+		    option_is_loose ? _("WARNING") : _("ERROR"), opt_str);
 	  if (option_is_loose)
 	  {
 	    (*argc)--;
@@ -445,7 +446,7 @@
 	      {
 		if (my_getopt_print_errors)
 		  fprintf(stderr,
-			  "%s: ERROR: Option '-%c' used, but is disabled\n",
+			  _("%s: ERROR: Option '-%c' used, but is disabled\n"),
 			  my_progname, optp->id);
 		return EXIT_OPTION_DISABLED;
 	      }
@@ -758,7 +759,7 @@
   else if (*endchar)
   {
     fprintf(stderr,
-	    "Unknown suffix '%c' used for variable '%s' (value '%s')\n",
+	    _("Unknown suffix '%c' used for variable '%s' (value '%s')\n"),
 	    *endchar, option_name, argument);
     *error= 1;
     return 0;
@@ -939,7 +940,7 @@
   if (end[0] != 0 || error)
   {
     fprintf(stderr,
-            "%s: ERROR: Invalid decimal value for option '%s'\n",
+            _("%s: ERROR: Invalid decimal value for option '%s'\n"),
             my_progname, optp->name);
     *err= EXIT_ARGUMENT_INVALID;
     return 0.0;
@@ -1141,7 +1142,7 @@
       putchar(' ');
     if (optp->comment && *optp->comment)
     {
-      const char *comment= gettext(optp->comment), *end= strend(comment);
+      const char *comment= _(optp->comment), *end= strend(comment);
 
       while ((uint) (end - comment) > comment_space)
       {
@@ -1161,7 +1162,7 @@
     {
       if (optp->def_value != 0)
       {
-        printf(gettext("%*s(Defaults to on; use --skip-%s to disable.)\n"), name_space, "", optp->name);
+        printf(_("%*s(Defaults to on; use --skip-%s to disable.)\n"), name_space, "", optp->name);
       }
     }
   }
@@ -1181,9 +1182,9 @@
   char buff[255];
   const struct my_option *optp;
 
-  printf("\nVariables (--variable-name=value)\n");
-  printf("and boolean options {false|true}  Value (after reading options)\n");
-  printf("--------------------------------- -----------------------------\n");
+  printf(_("\nVariables (--variable-name=value)\n"
+         "and boolean options {false|true}  Value (after reading options)\n"
+         "--------------------------------- -----------------------------\n"));
   for (optp= options; optp->id; optp++)
   {
     char* *value= (optp->var_type & GET_ASK_ADDR ?
@@ -1197,7 +1198,7 @@
       switch ((optp->var_type & GET_TYPE_MASK)) {
       case GET_SET:
         if (!(llvalue= *(uint64_t*) value))
-	  printf("%s\n", "(No default value)");
+	  printf("%s\n", _("(No default value)"));
 	else
         for (nr= 0, bit= 1; llvalue && nr < optp->typelib->count; nr++, bit<<=1)
 	{
@@ -1213,10 +1214,10 @@
       case GET_STR:
       case GET_STR_ALLOC:                    /* fall through */
 	printf("%s\n", *((char**) value) ? *((char**) value) :
-	       "(No default value)");
+	       _("(No default value)"));
 	break;
       case GET_BOOL:
-	printf("%s\n", *((bool*) value) ? "true" : "false");
+	printf("%s\n", *((bool*) value) ? _("true") : _("false"));
 	break;
       case GET_INT:
 	printf("%d\n", *((int*) value));
@@ -1241,7 +1242,7 @@
 	printf("%g\n", *(double*) value);
 	break;
       default:
-	printf("(Disabled)\n");
+	printf(_("(Disabled)\n"));
 	break;
       }
     }

=== modified file 'po/drizzle.pot'
--- po/drizzle.pot	2008-08-04 19:48:27 +0000
+++ po/drizzle.pot	2008-08-05 18:04:31 +0000
@@ -8,7 +8,7 @@
 msgstr ""
 "Project-Id-Version: drizzle 7.0.0\n"
 "Report-Msgid-Bugs-To: http://translations.launchpad.net/drizzle\n"
-"POT-Creation-Date: 2008-08-04 12:48-0700\n"
+"POT-Creation-Date: 2008-08-05 11:03-0700\n"
 "PO-Revision-Date: YEAR-MO-DA HO:MI+ZONE\n"
 "Last-Translator: FULL NAME <EMAIL@ADDRESS>\n"
 "Language-Team: LANGUAGE <LL@li.org>\n"
@@ -480,139 +480,139 @@
 msgid "WARNING: option deprecated; use --disable-pager instead.\n"
 msgstr ""
 
-#: client/drizzle.c:1565
+#: client/drizzle.c:1561
 #, c-format
 msgid "WARNING: --server-arg option not supported in this configuration.\n"
 msgstr ""
 
-#: client/drizzle.c:1936
+#: client/drizzle.c:1932
 #, c-format
 msgid "Unknown command '\\%c'."
 msgstr ""
 
-#: client/drizzle.c:2366
+#: client/drizzle.c:2362
 msgid ""
 "Reading table information for completion of table and column names\n"
 "    You can turn off this feature to get a quicker startup with -A\n"
 "\n"
 msgstr ""
 
-#: client/drizzle.c:2463
+#: client/drizzle.c:2459
 msgid "No connection. Trying to reconnect..."
 msgstr ""
 
-#: client/drizzle.c:2469
+#: client/drizzle.c:2465
 msgid "Can't connect to the server\n"
 msgstr ""
 
-#: client/drizzle.c:2526
+#: client/drizzle.c:2522
 msgid "categories:"
 msgstr ""
 
-#: client/drizzle.c:2526
+#: client/drizzle.c:2522
 msgid "topics:"
 msgstr ""
 
-#: client/drizzle.c:2577
+#: client/drizzle.c:2573
 #, c-format
 msgid "Name: '%s'\n"
 msgstr ""
 
-#: client/drizzle.c:2578
+#: client/drizzle.c:2574
 #, c-format
 msgid ""
 "Description:\n"
 "%s"
 msgstr ""
 
-#: client/drizzle.c:2580
+#: client/drizzle.c:2576
 #, c-format
 msgid ""
 "Examples:\n"
 "%s"
 msgstr ""
 
-#: client/drizzle.c:2593
+#: client/drizzle.c:2589
 msgid "Many help items for your request exist."
 msgstr ""
 
-#: client/drizzle.c:2594
+#: client/drizzle.c:2590
 msgid ""
 "To make a more specific request, please type 'help <item>',\n"
 "where <item> is one of the following"
 msgstr ""
 
-#: client/drizzle.c:2600
+#: client/drizzle.c:2596
 #, c-format
 msgid "You asked for help about help category: '%s'\n"
 msgstr ""
 
-#: client/drizzle.c:2601
+#: client/drizzle.c:2597
 msgid ""
 "For more information, type 'help <item>', where <item> is one of the "
 "following"
 msgstr ""
 
-#: client/drizzle.c:2614
+#: client/drizzle.c:2610
 msgid ""
 "\n"
 "Nothing found"
 msgstr ""
 
-#: client/drizzle.c:2615
+#: client/drizzle.c:2611
 msgid "Please try to run 'help contents' for a list of all accessible topics\n"
 msgstr ""
 
-#: client/drizzle.c:2638
+#: client/drizzle.c:2634
 msgid "List of all Drizzle commands:"
 msgstr ""
 
-#: client/drizzle.c:2640
+#: client/drizzle.c:2636
 msgid "Note that all text commands must be first on line and end with ';'"
 msgstr ""
 
-#: client/drizzle.c:2651
+#: client/drizzle.c:2647
 msgid ""
 "\n"
 "For server side help, type 'help contents'\n"
 msgstr ""
 
-#: client/drizzle.c:2674
+#: client/drizzle.c:2670
 msgid "Usage: \\C char_setname | charset charset_name"
 msgstr ""
 
-#: client/drizzle.c:2684
+#: client/drizzle.c:2680
 msgid "Charset changed"
 msgstr ""
 
-#: client/drizzle.c:2686
+#: client/drizzle.c:2682
 msgid "Charset is not found"
 msgstr ""
 
-#: client/drizzle.c:2717
+#: client/drizzle.c:2713
 msgid "No query specified\n"
 msgstr ""
 
-#: client/drizzle.c:2732
+#: client/drizzle.c:2728
 msgid "Ignoring query to other database"
 msgstr ""
 
-#: client/drizzle.c:2781
+#: client/drizzle.c:2777
 msgid "Empty set"
 msgstr ""
 
-#: client/drizzle.c:2808
+#: client/drizzle.c:2804
 #, c-format
 msgid "%ld row in set"
 msgid_plural "%ld rows in set"
 msgstr[0] ""
 msgstr[1] ""
 
-#: client/drizzle.c:2817
+#: client/drizzle.c:2813
 msgid "Query OK"
 msgstr ""
 
-#: client/drizzle.c:2819
+#: client/drizzle.c:2815
 #, c-format
 msgid "Query OK, %ld row affected"
 msgid_plural "Query OK, %ld rows affected"
@@ -773,11 +773,73 @@
 msgid "Unknown error %d"
 msgstr ""
 
-#: mysys/my_getopt.c:1164
+#: mysys/my_getopt.c:83
+msgid "Warning: "
+msgstr ""
+
+#: mysys/my_getopt.c:85
+msgid "Info: "
+msgstr ""
+
+#: mysys/my_getopt.c:345
+#, c-format
+msgid "%s: %s: Option '%s' used, but is disabled\n"
+msgstr ""
+
+#: mysys/my_getopt.c:346
+msgid "WARNING"
+msgstr ""
+
+#: mysys/my_getopt.c:346
+msgid "ERROR"
+msgstr ""
+
+#: mysys/my_getopt.c:449
+#, c-format
+msgid "%s: ERROR: Option '-%c' used, but is disabled\n"
+msgstr ""
+
+#: mysys/my_getopt.c:762
+#, c-format
+msgid "Unknown suffix '%c' used for variable '%s' (value '%s')\n"
+msgstr ""
+
+#: mysys/my_getopt.c:943
+#, c-format
+msgid "%s: ERROR: Invalid decimal value for option '%s'\n"
+msgstr ""
+
+#: mysys/my_getopt.c:1165
 #, c-format
 msgid "%*s(Defaults to on; use --skip-%s to disable.)\n"
 msgstr ""
 
+#: mysys/my_getopt.c:1185
+#, c-format
+msgid ""
+"\n"
+"Variables (--variable-name=value)\n"
+"and boolean options {false|true}  Value (after reading options)\n"
+"--------------------------------- -----------------------------\n"
+msgstr ""
+
+#: mysys/my_getopt.c:1201 mysys/my_getopt.c:1217
+msgid "(No default value)"
+msgstr ""
+
+#: mysys/my_getopt.c:1220
+msgid "true"
+msgstr ""
+
+#: mysys/my_getopt.c:1220
+msgid "false"
+msgstr ""
+
+#: mysys/my_getopt.c:1245
+#, c-format
+msgid "(Disabled)\n"
+msgstr ""
+
 #: mysys/my_handler_errors.h:10
 msgid "Didn't find key on read or update"
 msgstr ""
@@ -1507,75 +1569,75 @@
 msgid "Failed in send_file() while negotiating file transfer close"
 msgstr ""
 
-#: drizzled/table.cc:546
+#: drizzled/table.cc:547
 #, c-format
 msgid ""
 "'%s' had no or invalid character set, and default character set is multi-"
 "byte, so character column sizes may have changed"
 msgstr ""
 
-#: drizzled/table.cc:983 drizzled/table.cc:989
+#: drizzled/table.cc:984 drizzled/table.cc:990
 #, c-format
 msgid ""
 "Found incompatible DECIMAL field '%s' in %s; Please do \"ALTER TABLE '%s' "
 "FORCE\" to fix it!"
 msgstr ""
 
-#: drizzled/table.cc:1161
+#: drizzled/table.cc:1162
 #, c-format
 msgid ""
 "Found wrong key definition in %s; Please do \"ALTER TABLE '%s' FORCE \" to "
 "fix it!"
 msgstr ""
 
-#: drizzled/table.cc:1167
+#: drizzled/table.cc:1168
 #, c-format
 msgid ""
 "Found wrong key definition in %s; Please do \"ALTER TABLE '%s' FORCE\" to "
 "fix it!"
 msgstr ""
 
-#: drizzled/table.cc:1810
+#: drizzled/table.cc:1811
 #, c-format
 msgid "Unknown collation '%s' in table '%-.64s' definition"
 msgstr ""
 
-#: drizzled/table.cc:1817
+#: drizzled/table.cc:1818
 #, c-format
 msgid ""
 "Table '%-.64s' was created with a different version of MySQL and cannot be "
 "read"
 msgstr ""
 
-#: drizzled/table.cc:2406
+#: drizzled/table.cc:2409
 #, c-format
 msgid ""
 "Incorrect definition of table %s.%s: expected column '%s' at position %d, "
 "found '%s'."
 msgstr ""
 
-#: drizzled/table.cc:2432
+#: drizzled/table.cc:2435
 #, c-format
 msgid ""
 "Incorrect definition of table %s.%s: expected column '%s' at position %d to "
 "have type %s, found type %s."
 msgstr ""
 
-#: drizzled/table.cc:2441
+#: drizzled/table.cc:2444
 #, c-format
 msgid ""
 "Incorrect definition of table %s.%s: expected the type of column '%s' at "
 "position %d to have character set '%s' but the type has no character set."
 msgstr ""
 
-#: drizzled/table.cc:2451
+#: drizzled/table.cc:2454
 #, c-format
 msgid ""
 "Incorrect definition of table %s.%s: expected the type of column '%s' at "
 "position %d to have character set '%s' but found character set '%s'."
 msgstr ""
 
-#: drizzled/table.cc:2462
+#: drizzled/table.cc:2465
 #, c-format
 msgid ""
 "Incorrect definition of table %s.%s: expected column '%s' at position %d to "

